@@ -1,5 +1,5 @@
 #
-# Copyright (c) 2020, 2021  Peter Pentchev <roam@ringlet.net>
+# Copyright (c) 2020 - 2022  Peter Pentchev <roam@ringlet.net>
 # All rights reserved.
 #
 # Redistribution and use in source and binary forms, with or without
@@ -139,7 +139,8 @@ def version_compare_split(spl_a: List[str], spl_b: List[str]) -> int:
     if res is not None:
         return res
 
-    (first_a, first_b) = (spl_a.pop(0), spl_b.pop(0))
+    first_a, *spl_a = spl_a
+    first_b, *spl_b = spl_b
     (num_a, rem_a) = _version_split_num_alpha(first_a)
     assert num_a != "" or rem_a != "", "could not split " + first_a
     (num_b, rem_b) = _version_split_num_alpha(first_b)
