@@ -30,6 +30,7 @@ import unittest
 import ddt  # type: ignore
 
 import trivver
+import trivver.trivver as trivver_inner
 
 from . import data
 
@@ -59,3 +60,12 @@ class TestVersions(unittest.TestCase):
     def test_sort(self) -> None:
         """Sort a list of versions."""
         assert sorted(data.UNSORTED, key=trivver.key_compare) == data.SORTED
+
+
+def test_immutable() -> None:
+    """Make sure version_compare_split() does not modify its arguments."""
+    first = ["0", "4", "1"]
+    second = ["0", "4", "2"]
+    assert sign(trivver_inner.version_compare_split(first, second)) == -1
+    assert first == ["0", "4", "1"]
+    assert second == ["0", "4", "2"]
